File 0768-Fix-typos.patch of Package erlang

From e12bfe5648b7134517ba5fd7104dbd8c94039853 Mon Sep 17 00:00:00 2001
From: "Kian-Meng, Ang" <kianmeng@cpan.org>
Date: Fri, 3 Dec 2021 06:37:36 +0800
Subject: [PATCH] Fix typos
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

Co-authored-by: Björn Gustavsson <bgustavsson@gmail.com>
---
 lib/asn1/c_src/asn1_erl_nif.c                  |  8 ++++----
 lib/asn1/doc/src/notes.xml                     |  6 +++---
 lib/asn1/examples/ecn_internaldoc.txt          |  2 +-
 lib/asn1/examples/encode_decode_formats.txt    |  2 +-
 lib/asn1/notes.html                            | 10 +++++-----
 lib/asn1/src/asn1ct.erl                        | 10 +++++-----
 lib/asn1/src/asn1ct_check.erl                  | 18 +++++++++---------
 lib/asn1/src/asn1ct_gen.erl                    |  2 +-
 lib/asn1/src/asn1ct_gen_ber_bin_v2.erl         |  4 ++--
 lib/asn1/src/asn1ct_gen_jer.erl                |  2 +-
 lib/asn1/src/asn1ct_parser2.erl                |  2 +-
 lib/asn1/src/asn1ct_pretty_format.erl          |  2 +-
 lib/asn1/src/asn1ct_tok.erl                    |  2 +-
 lib/asn1/src/asn1rtt_ber.erl                   |  4 ++--
 lib/asn1/src/asn1rtt_real_common.erl           |  2 +-
 lib/asn1/test/asn1_SUITE_data/Comment.asn      |  2 +-
 .../test/asn1_SUITE_data/CommonDataTypes.py    |  6 +++---
 .../asn1_SUITE_data/EUTRA-RRC-Definitions.asn  |  2 +-
 .../asn1_SUITE_data/H235-SECURITY-MESSAGES.asn |  2 +-
 .../test/asn1_SUITE_data/IN-CS-1-Datatypes.asn |  2 +-
 lib/asn1/test/asn1_SUITE_data/Mvrasn-11-4.asn  |  4 ++--
 lib/asn1/test/asn1_SUITE_data/Nortel.asn       |  4 ++--
 .../test/asn1_SUITE_data/PKIX1Explicit93.asn1  |  2 +-
 lib/asn1/test/asn1_SUITE_data/RANAP.asn1       |  4 ++--
 lib/asn1/test/asn1_SUITE_data/SwCDR.py         |  2 +-
 .../nbapsystem/NBAP-PDU-Contents.asn           |  6 +++---
 .../rfcs/AlgorithmInformation-2009.asn1        |  2 +-
 .../asn1_SUITE_data/rfcs/ISO8571-FTAM.asn1     |  6 +++---
 .../tcapsystem/MAP-MS-DataTypes.asn            |  2 +-
 lib/asn1/test/asn1_SUITE_data/testobj.erl      | 10 +++++-----
 lib/asn1/test/syntax_SUITE.erl                 |  2 +-
 31 files changed, 67 insertions(+), 67 deletions(-)

diff --git a/lib/asn1/c_src/asn1_erl_nif.c b/lib/asn1/c_src/asn1_erl_nif.c
index e9c597f842..306b3a178c 100644
--- a/lib/asn1/c_src/asn1_erl_nif.c
+++ b/lib/asn1/c_src/asn1_erl_nif.c
@@ -228,7 +228,7 @@ static int per_complete(ErlNifBinary *out_binary, unsigned char *in_buf,
 
 	case 30:
 	    /* If we call the following bytes, in the buffer in_ptr points at,
-	     By1,By2,Rest then Rest is the value that will be transfered to
+	     By1,By2,Rest then Rest is the value that will be transferred to
 	     the completed buffer. By1 tells how many of the rightmost bits in
 	     Rest that should not be used. By2 is the length of Rest in bytes.*/
 	    in_unused = (int) *(++in_ptr);
@@ -245,7 +245,7 @@ static int per_complete(ErlNifBinary *out_binary, unsigned char *in_buf,
 
 	case 31:
 	    /* If we call the following bytes, in the buffer in_ptr points at,
-	     By1,By2,By3,Rest then Rest is the value that will be transfered to
+	     By1,By2,By3,Rest then Rest is the value that will be transferred to
 	     the completed buffer. By1 tells how many of the rightmost bits in
 	     Rest that should not be used. By2 and By3 is the length of
 	     Rest in bytes.*/
@@ -834,7 +834,7 @@ static int per_insert_octets_except_unused(int no_bytes, unsigned char **input_p
  * List is like: [{TagNo,Value},{TagNo,Value},...]
  * Rest is a binary, i.e. the undecoded part of the buffer. Most often Rest
  * is the empty binary.
- * If some error occured during the decoding of the in_buf an error is returned.
+ * If some error occurred during the decoding of the in_buf an error is returned.
  */
 static int ber_decode_begin(ErlNifEnv* env, ERL_NIF_TERM *term, unsigned char *in_buf,
 	int in_buf_len, unsigned int *err_pos) {
@@ -1087,7 +1087,7 @@ static int ber_encode(ErlNifEnv *env, ERL_NIF_TERM term, mem_chunk_t **curr, uns
     }
     }
 
-    // We need atleast 5 bytes to encode the next tlv
+    // We need at least 5 bytes to encode the next tlv
     if (ber_check_memory(curr, 3))
 	return ASN1_ERROR;
 
diff --git a/lib/asn1/doc/src/notes.xml b/lib/asn1/doc/src/notes.xml
index 0c4c865faa..ca5d659980 100644
--- a/lib/asn1/doc/src/notes.xml
+++ b/lib/asn1/doc/src/notes.xml
@@ -327,7 +327,7 @@
 	    decoding a recursively enclosed term the length was not
 	    propagated to that term decoding, so if the length of the
 	    enclosed term was longer than the enclosing that error
-	    was not dectected</p> <p>A hard coded C stack limitation
+	    was not detected</p> <p>A hard coded C stack limitation
 	    for decoding recursive ASN.1 terms has been introduced.
 	    This is currently set to 8 kWords giving a nesting depth
 	    of about 1000 levels. Deeper terms can not be decoded,
@@ -389,7 +389,7 @@
         <item>
           <p>
 	    Compiling an ASN.1 module using the option {n2n,
-	    EnumTypeName} when EnumTypeName contains a hypen like for
+	    EnumTypeName} when EnumTypeName contains a hyphen like for
 	    example Cause-Misc caused syntax errors when compiling
 	    the generated Erlang code. This is now corrected.</p>
           <p>
@@ -1044,7 +1044,7 @@
         <item>
 	    <p>The ASN.1 compiler will now always include necessary
 	    run-time functions in the generated Erlang modules
-	    (except for <c>asn1rt_nif</c> which is still neeeded). If
+	    (except for <c>asn1rt_nif</c> which is still needed). If
 	    the option '<c>inline</c>' is used the ASN.1 compiler
 	    will generate a warning. But if
 	    '<c>{inline,OutputFile}</c>' is use, the ASN.1 compiler
diff --git a/lib/asn1/examples/ecn_internaldoc.txt b/lib/asn1/examples/ecn_internaldoc.txt
index 71e2b7a2f1..909adc6fe8 100644
--- a/lib/asn1/examples/ecn_internaldoc.txt
+++ b/lib/asn1/examples/ecn_internaldoc.txt
@@ -27,7 +27,7 @@ enable the use of ECN in the OTP ASN1 compiler.
        - Unaligned PER backend. Often seems the unaligned PER encoding
        as the prefferred main method in ECN applications. One of the
        goals with ECN is to use less space for encoding to decrease
-       the use of bandwith in transmission. This goal is highly
+       the use of bandwidth in transmission. This goal is highly
        supported by unaligned PER.
 
 
diff --git a/lib/asn1/examples/encode_decode_formats.txt b/lib/asn1/examples/encode_decode_formats.txt
index 62774cf13b..5b5748c196 100644
--- a/lib/asn1/examples/encode_decode_formats.txt
+++ b/lib/asn1/examples/encode_decode_formats.txt
@@ -13,4 +13,4 @@ per_bin, optimize	      | 	binary	      | binary	        |
 
 
 
-iolist: deep list with binaries and lists as componets
\ No newline at end of file
+iolist: deep list with binaries and lists as components
\ No newline at end of file
diff --git a/lib/asn1/notes.html b/lib/asn1/notes.html
index c7da5496c8..9e3feefef7 100644
--- a/lib/asn1/notes.html
+++ b/lib/asn1/notes.html
@@ -52,7 +52,7 @@
 
   <li>An error due to unchecked referenced imported type resulted
   in missing tag in some table constraint cases. This error is
-  now corrected. Error occured during decode in 
+  now corrected. Error occurred during decode in 
   <c>ber_bin optimized</c> version.
   (Own Id: OTP-5022)<p>
   </li>
@@ -103,7 +103,7 @@
   </li>
 
   <li>
-  Object Identifier values with two components and teh first was a
+  Object Identifier values with two components and the first was a
   value reference failed due to parsing conflicts. Now it is
   corrected.
   (Own Id: OTP-4895)<p>
@@ -195,12 +195,12 @@
 <ul>
 
   <li>
-  The <c>{internal_error,...,{ unrecognized_type,...}}</c> error occuring for a SET type when compiling with options <c>[ber_bin,optimize,der]</c> is now corrected.
+  The <c>{internal_error,...,{ unrecognized_type,...}}</c> error occurring for a SET type when compiling with options <c>[ber_bin,optimize,der]</c> is now corrected.
   (Own Id: OTP-4866)<p>
   </li>
 
   <li>
-  False encode of BIT STRING in PER (per_bin,optimize) is fixed. The error occured when there was a type like BIT STRING (SIZE(C)) and C > 16.
+  False encode of BIT STRING in PER (per_bin,optimize) is fixed. The error occurred when there was a type like BIT STRING (SIZE(C)) and C > 16.
   (Own Id: OTP-4869)<p>
   </li>
 
@@ -222,7 +222,7 @@
   </li>
 
   <li>
-  Bug causing duplicated fuction definitions using exclusive decode is removed.<br>
+  Bug causing duplicated function definitions using exclusive decode is removed.<br>
   (Own Id: OTP-4833)<p>
   </li>
 
diff --git a/lib/asn1/src/asn1ct.erl b/lib/asn1/src/asn1ct.erl
index b84fdd0f04..7c67a7f637 100644
--- a/lib/asn1/src/asn1ct.erl
+++ b/lib/asn1/src/asn1ct.erl
@@ -394,7 +394,7 @@ remove_name_collisions(Modules) ->
     remove_name_collisions2(Modules,[]).
 
 %% For each definition in the first module in module list, find
-%% all definitons with same name and rename both definitions in
+%% all definitions with same name and rename both definitions in
 %% the first module and in rest of modules
 remove_name_collisions2([M|Ms],Acc) ->
     TypeOrVal = M#module.typeorval,
@@ -721,7 +721,7 @@ save_automatic_tagged_types([_M|Ms]) ->
 %% remove_in_set_imports/3 :
 %% input: list with tuples of each module's imports and module name 
 %% respectively.
-%% output: one list with same format but each occured import from a
+%% output: one list with same format but each occurred import from a
 %% module in the input set (IMNameL) is removed.
 remove_in_set_imports([{{imports,ImpL},_ModName}|Rest],InputMNameL,Acc) ->
     NewImpL = remove_in_set_imports1(ImpL,InputMNameL,[]),
@@ -1454,12 +1454,12 @@ special_decode_prepare_1(#gen{options=Options}=Gen, M) ->
 
 %% create_partial_inc_decode_gen_info/2
 %%
-%% Creats a list of tags out of the information in TypeNameList that
+%% Creates a list of tags out of the information in TypeNameList that
 %% tells which value will be incomplete decoded, i.e. each end
 %% component/type in TypeNameList. The significant types/components in
 %% the path from the toptype must be specified in the
 %% TypeNameList. Significant elements are all constructed types that
-%% branches the path to the leaf and the leaf it selfs.
+%% branches the path to the leaf and the leaf it self.
 %%
 %% Returns a list of elements, where an element may be one of
 %% mandatory|[opt,Tag]|[bin,Tag]. mandatory correspond to a mandatory
@@ -1621,7 +1621,7 @@ partial_inc_dec_toptype(_) ->
     throw({error,{"no top type found for partial incomplete decode"}}).
 
 
-%% Creats a list of tags out of the information in TypeList and Types
+%% Creates a list of tags out of the information in TypeList and Types
 %% that tells which value will be decoded.  Each constructed type that
 %% is in the TypeList will get a "choosen" command. Only the last
 %% type/component in the TypeList may be a primitive type. Components
diff --git a/lib/asn1/src/asn1ct_check.erl b/lib/asn1/src/asn1ct_check.erl
index b9bea8e843..9cd8a48a1b 100644
--- a/lib/asn1/src/asn1ct_check.erl
+++ b/lib/asn1/src/asn1ct_check.erl
@@ -695,7 +695,7 @@ check_object(S,_ObjDef,#'Object'{classname=ClassRef,def=ObjectDef}) ->
 	    {po,{object,DefObj},ArgsList} ->
 		{_,Object} = get_referenced_type(S,DefObj),%DefObj is a 
 		%%#'Externalvaluereference' or a #'Externaltypereference'
-		%% Maybe this call should be catched and in case of an exception
+		%% Maybe this call should be caught and in case of an exception
 		%% a not initialized parameterized object should be returned.
 		instantiate_po(S,ClassDef,Object,ArgsList);
 	    {pv,{simpledefinedvalue,ObjRef},ArgList} ->
@@ -1170,7 +1170,7 @@ gen_incl1(_,_,[]) ->
 gen_incl1(S,Fields,[C|CFields]) ->
     case element(1,C) of
 	typefield ->
-	    true; %% should check that field is OPTIONAL or DEFUALT if
+	    true; %% should check that field is OPTIONAL or DEFAULT if
                   %% the object lacks this field
 	objectfield ->
 	    case lists:keysearch(element(2,C),1,Fields) of
@@ -2409,7 +2409,7 @@ normalize_s_of(SorS,S,Value,Type,NameList)
 %% character string list case
 normalize_restrictedstring(S,[H|T],CType) when is_list(H);is_tuple(H) ->
     [normalize_restrictedstring(S,H,CType)|normalize_restrictedstring(S,T,CType)];
-%% character sting case
+%% character string case
 normalize_restrictedstring(_S,CString,_) when is_list(CString) ->
     CString;
 %% definedvalue case or argument in a parameterized type
@@ -2816,7 +2816,7 @@ check_type(S=#state{recordtopname=TopName},Type,Ts) when is_record(Ts,type) ->
 				inlined=yes};
 
 	    #'ObjectClassFieldType'{classname=ClRef0}=OCFT0 ->
-		%% this case occures in a SEQUENCE when 
+		%% this case occurs in a SEQUENCE when 
 		%% the type of the component is a ObjectClassFieldType
 		ClRef = match_parameter(S, ClRef0),
 		OCFT = OCFT0#'ObjectClassFieldType'{classname=ClRef},
@@ -3427,10 +3427,10 @@ check_componentrelation(S, {objectset,Opos,Objset0}, Id) ->
 %%% creating sets, and maintained by the intersection and union
 %%% operators.
 %%%
-%%% Example of invalid set representaions:
+%%% Example of invalid set representations:
 %%%
 %%%   [{range,0,10},{range,5,10}]    %Overlapping ranges
-%%%   [{range,0,5},{range,6,10}]     %Adjancent ranges
+%%%   [{range,0,5},{range,6,10}]     %Adjacent ranges
 %%%   [{range,10,20},{a_range,100}]  %Not sorted
 %%%
 
@@ -4388,7 +4388,7 @@ check_sequence(S,Type,Comps)  ->
 	    %% type
 	    {CRelInf,NewComps2} = componentrelation_leadingattr(S,NewComps),
 
-	    %% CompListWithTblInf has got a lot unecessary info about
+	    %% CompListWithTblInf has got a lot unnecessary info about
 	    %% the involved class removed, as the class of the object
 	    %% set.
 	    CompListWithTblInf = get_tableconstraint_info(S,Type,NewComps2),
@@ -5183,7 +5183,7 @@ any_component_relation(_,[],_,_,Acc) ->
 %% evaluate_atpath/4 finds out whether the at notation refers to the
 %% search level. The list of referenced names in the AtNot list shall
 %% begin with a name that exists on the level it refers to. If the
-%% found AtPath is refering to the same sub-branch as the simple table
+%% found AtPath is referring to the same sub-branch as the simple table
 %% has, then there shall not be any leading attribute info on this
 %% level.
 evaluate_atpath(_,[],Cnames,{innermost,AtPath=[Ref|_Refs]}) ->
@@ -5354,7 +5354,7 @@ innertype_comprel1(S,T = #type{def=Def,constraint=Cons,tablecinf=TCI},Path) ->
 	case lists:keyfind(componentrelation, 1, Cons) of
 	    {_,{_,_,ObjectSet},AtList} ->
 		%% This AtList must have an "outermost" at sign to be
-		%% relevent here.
+		%% relevant here.
 		[{_,AL=[#'Externalvaluereference'{value=_Attr}|_R1]}|_R2] 
 		    = AtList,
 		ClassDef = get_ObjectClassFieldType_classdef(S,Def),
diff --git a/lib/asn1/src/asn1ct_gen.erl b/lib/asn1/src/asn1ct_gen.erl
index 1a27eb0b02..217f4f5d8a 100644
--- a/lib/asn1/src/asn1ct_gen.erl
+++ b/lib/asn1/src/asn1ct_gen.erl
@@ -264,7 +264,7 @@ gen_partial_inc_dec_refed_funcs(Rtmod, #gen{erule=ber}=Gen) ->
 
 pgen_partial_dec(_Rtmod,Erules,_Module) ->
     Type_pattern = asn1ct:get_gen_state_field(type_pattern),
-    %% Get the typedef of the top type and follow into the choosen
+    %% Get the typedef of the top type and follow into the chosen
     %% components until the last type/component.
     pgen_partial_types(Erules,Type_pattern),
     ok.
diff --git a/lib/asn1/src/asn1ct_gen_ber_bin_v2.erl b/lib/asn1/src/asn1ct_gen_ber_bin_v2.erl
index 446f508998..6a358c5600 100644
--- a/lib/asn1/src/asn1ct_gen_ber_bin_v2.erl
+++ b/lib/asn1/src/asn1ct_gen_ber_bin_v2.erl
@@ -764,7 +764,7 @@ gen_encode_objectfields(ClassName,[{typefield,Name,OptOrMand}|Rest],
 		EmitFuncClause("Val"),
 		gen_encode_default_call(ClassName,Name,DefaultType);
 	    {{Name,TypeSpec},_} ->
-		%% A specified field owerwrites any 'DEFAULT' or
+		%% A specified field overwrites any 'DEFAULT' or
 		%% 'OPTIONAL' field in the class
 		EmitFuncClause("Val"),
 		gen_encode_field_call(ObjName,Name,TypeSpec)
@@ -912,7 +912,7 @@ gen_decode_objectfields(ClassName,[{typefield,Name,OptOrMand}|Rest],
 		emit_tlv_format("Bytes"),
 		gen_decode_default_call(ClassName,Name,"Tlv",DefaultType);
 	    {{Name,TypeSpec},_} ->
-		%% A specified field owerwrites any 'DEFAULT' or
+		%% A specified field overwrites any 'DEFAULT' or
 		%% 'OPTIONAL' field in the class
 		EmitFuncClause("Bytes"),
 		emit_tlv_format("Bytes"),
diff --git a/lib/asn1/src/asn1ct_gen_jer.erl b/lib/asn1/src/asn1ct_gen_jer.erl
index 041ea6b247..ebc882ffbc 100644
--- a/lib/asn1/src/asn1ct_gen_jer.erl
+++ b/lib/asn1/src/asn1ct_gen_jer.erl
@@ -523,7 +523,7 @@ maybe_legacy_bit_string(BitStrType,SizeConstraint) ->
 %%===========================================================================
 %% Generate DECODING
 %%===========================================================================
-%% dummy functions beause we don't generate anything special for decode 
+%% dummy functions because we don't generate anything special for decode 
 %%===========================================================================
 
 gen_decode(_,_) -> ok.
diff --git a/lib/asn1/src/asn1ct_parser2.erl b/lib/asn1/src/asn1ct_parser2.erl
index 35c921e98d..646657b744 100644
--- a/lib/asn1/src/asn1ct_parser2.erl
+++ b/lib/asn1/src/asn1ct_parser2.erl
@@ -1106,7 +1106,7 @@ parse_ObjectAssignment([#identifier{pos=L1,val=ObjName}|Rest]) ->
 %% Ret       = {object,_} | {object, _, _}
 parse_Object(Tokens) ->
     %% The ObjectFromObject production is not included here,
-    %% since it will have been catched by the ValueFromObject
+    %% since it will have been caught by the ValueFromObject
     %% before we reach this point.
     Flist = [fun parse_ObjectDefn/1,
 	     fun parse_DefinedObject/1],
diff --git a/lib/asn1/src/asn1ct_pretty_format.erl b/lib/asn1/src/asn1ct_pretty_format.erl
index f4669f7eb0..2b50a390d4 100644
--- a/lib/asn1/src/asn1ct_pretty_format.erl
+++ b/lib/asn1/src/asn1ct_pretty_format.erl
@@ -51,7 +51,7 @@ term(Term) ->
 %%______________________________________________________________________
 %% pretty_format:term(Term, Indent} -> {Indent', Chars}
 %%   Format <Term> -- use <Indent> to indent the *next* line
-%%     Note: Indent' is a new indentaion level (sometimes printing <Term>
+%%     Note: Indent' is a new indentation level (sometimes printing <Term>
 %%     the next line to need an "extra" indent!).
 
 term([], Indent) ->
diff --git a/lib/asn1/src/asn1ct_tok.erl b/lib/asn1/src/asn1ct_tok.erl
index 76ff60f9cf..bf6974cc50 100644
--- a/lib/asn1/src/asn1ct_tok.erl
+++ b/lib/asn1/src/asn1ct_tok.erl
@@ -171,7 +171,7 @@ collect_string([], _, _) ->
     throw({error,missing_quote_at_eof}).
            
 %% <name> is letters digits hyphens.
-%% Hypen is not the last character. Hypen hyphen is NOT allowed.
+%% Hyphen is not the last character. Hyphen hyphen is NOT allowed.
 %%
 %% <identifier> ::= <lowercase> <name>
 
diff --git a/lib/asn1/src/asn1rtt_ber.erl b/lib/asn1/src/asn1rtt_ber.erl
index d1cd22579b..1752da424e 100644
--- a/lib/asn1/src/asn1rtt_ber.erl
+++ b/lib/asn1/src/asn1rtt_ber.erl
@@ -774,7 +774,7 @@ do_encode_named_bit_string(Size, [FirstVal | RestVal], NamedBitList, TagIn) ->
 %%
 %% bitstring NamedBitList
 %% Val can be  of:
-%% - [identifiers] where only named identifers are set to one,
+%% - [identifiers] where only named identifiers are set to one,
 %%   the Constraint must then have some information of the
 %%   bitlength.
 %% - [list of ones and zeroes] all bits
@@ -1133,7 +1133,7 @@ e_object_identifier(V) when is_tuple(V) ->
     e_object_identifier(tuple_to_list(V));
 
 %%%%%%%%%%%%%%%
-%% e_object_identifier([List of Obect Identifiers]) ->
+%% e_object_identifier([List of Object Identifiers]) ->
 %% {[Encoded Octetlist of ObjIds], IntLength}
 %%
 e_object_identifier([E1,E2|Tail]) ->
diff --git a/lib/asn1/src/asn1rtt_real_common.erl b/lib/asn1/src/asn1rtt_real_common.erl
index 0d53447eb7..6d2bc34f35 100644
--- a/lib/asn1/src/asn1rtt_real_common.erl
+++ b/lib/asn1/src/asn1rtt_real_common.erl
@@ -222,7 +222,7 @@ decode_real2(Buffer0, _C, Len, RemBytes1) ->
 	First =:= 2#01000000 -> {'PLUS-INFINITY', Buffer2};
 	First =:= 2#01000001 -> {'MINUS-INFINITY', Buffer2};
 	First =:= 1 orelse First =:= 2 orelse First =:= 3 ->
-	    %% charcter string encoding of base 10
+	    %% character string encoding of base 10
 	    {NRx,Rest} = split_binary(Buffer2,Len-1),
 	    {binary_to_list(NRx),Rest,Len};
 	true ->
diff --git a/lib/asn1/test/asn1_SUITE_data/Comment.asn b/lib/asn1/test/asn1_SUITE_data/Comment.asn
index c2a5abd633..af439a1ce4 100644
--- a/lib/asn1/test/asn1_SUITE_data/Comment.asn
+++ b/lib/asn1/test/asn1_SUITE_data/Comment.asn
@@ -4,7 +4,7 @@ BEGIN
 
 /* comments as to the 2002 standard
 
-this is the new added way of commenting multile lines */
+this is the new added way of commenting multiple lines */
 
 /* it is also allowed to have -- old kind of comment signs inside
 this new variant. The two dashes will lose their meaning as a comment
diff --git a/lib/asn1/test/asn1_SUITE_data/CommonDataTypes.py b/lib/asn1/test/asn1_SUITE_data/CommonDataTypes.py
index 2c25f81235..67cd9eae96 100644
--- a/lib/asn1/test/asn1_SUITE_data/CommonDataTypes.py
+++ b/lib/asn1/test/asn1_SUITE_data/CommonDataTypes.py
@@ -923,7 +923,7 @@ ConnectUUIE ::= SEQUENCE
 --   @prop	dataType
 --
 --   @descr	This parameter holds connection data that are specific for   
---   		certain types of Equipments.
+--   		certain types of Equipment.
 --   @
 --
 -- ---------------------------------
@@ -958,7 +958,7 @@ ConnectionIdentifier ::= ObjectIdentifier
 --   @prop	dataType
 --
 --   @descr	This parameter specifies information that are of interest for 
---   		the functionallity handled by component Connection Handler. 
+--   		the functionality handled by component Connection Handler. 
 --   @
 --
 -- ---------------------------------
@@ -1541,7 +1541,7 @@ EquipmentAddressLAN ::= SEQUENCE
 --
 --   @prop	dataType
 --
---   @descr	Contains the retreived data.
+--   @descr	Contains the retrieved data.
 --
 --   @
 --
diff --git a/lib/asn1/test/asn1_SUITE_data/EUTRA-RRC-Definitions.asn b/lib/asn1/test/asn1_SUITE_data/EUTRA-RRC-Definitions.asn
index 3b811dafe6..24dd8e85e8 100644
--- a/lib/asn1/test/asn1_SUITE_data/EUTRA-RRC-Definitions.asn
+++ b/lib/asn1/test/asn1_SUITE_data/EUTRA-RRC-Definitions.asn
@@ -3124,7 +3124,7 @@ maxCellMeas					INTEGER ::= 32	-- Maximum number of entries in each of the neigh
 											-- cell lists in a measurement object
 maxCellReport				INTEGER ::= 8	-- Maximum number of reported cells
 maxDRB						INTEGER ::= 11	-- Maximum number of Data Radio Bearers
-maxEARFCN					INTEGER ::= 65535	-- Maximum value of EUTRA carrier fequency
+maxEARFCN					INTEGER ::= 65535	-- Maximum value of EUTRA carrier frequency
 maxFreq						INTEGER ::= 8	-- Maximum number of EUTRA carrier frequencies
 maxCellInfo-GERAN-r9 		INTEGER ::=	32	-- Maximum number of GERAN cells for which system in-
 											-- formation can be provided as redirection assistance
diff --git a/lib/asn1/test/asn1_SUITE_data/H235-SECURITY-MESSAGES.asn b/lib/asn1/test/asn1_SUITE_data/H235-SECURITY-MESSAGES.asn
index 3401f9599f..76eedc0d2c 100644
--- a/lib/asn1/test/asn1_SUITE_data/H235-SECURITY-MESSAGES.asn
+++ b/lib/asn1/test/asn1_SUITE_data/H235-SECURITY-MESSAGES.asn
@@ -135,7 +135,7 @@ KeySignedMaterial ::= SEQUENCE {
 	generalId		Identifier, -- slave's alias
 	mrandom	RandomVal, -- master's random value
 	srandom	RandomVal OPTIONAL, -- slave's random value
-	timeStamp	TimeStamp OPTIONAL, -- master's timestamp for unsolicted EU
+	timeStamp	TimeStamp OPTIONAL, -- master's timestamp for unsolicited EU
 	encrptval	ENCRYPTED {EncodedKeySyncMaterial }
 }
 EncodedKeySignedMaterial ::= TYPE-IDENTIFIER.&Type (KeySignedMaterial)
diff --git a/lib/asn1/test/asn1_SUITE_data/IN-CS-1-Datatypes.asn b/lib/asn1/test/asn1_SUITE_data/IN-CS-1-Datatypes.asn
index fb092f3f9c..9cd8fbea84 100644
--- a/lib/asn1/test/asn1_SUITE_data/IN-CS-1-Datatypes.asn
+++ b/lib/asn1/test/asn1_SUITE_data/IN-CS-1-Datatypes.asn
@@ -1431,7 +1431,7 @@ ServiceInteractionIndicators ::=
 -- The following example is listed to illustrate the use of this parameter:
 --	CallToBeDiverted	Allowed/NotAllowed Indicator
 -- If the CallToBeDiverted indicator is set to NotAllowed, the destination exchange shall not allow any
--- divertion on the subjected call. By this, each service can pass the applicable indicators to inform the
+-- diversion on the subjected call. By this, each service can pass the applicable indicators to inform the
 -- destination exchange of how specific services are to be handled.
 ServiceKey ::=
   Integer4
diff --git a/lib/asn1/test/asn1_SUITE_data/Mvrasn-11-4.asn b/lib/asn1/test/asn1_SUITE_data/Mvrasn-11-4.asn
index 81c07a2dab..fca635bb1f 100644
--- a/lib/asn1/test/asn1_SUITE_data/Mvrasn-11-4.asn
+++ b/lib/asn1/test/asn1_SUITE_data/Mvrasn-11-4.asn
@@ -140,8 +140,8 @@ InsertSubscriberDataArg ::= SEQUENCE {
 -- compiler. Instead of this line the complete definition of 
 -- "Subscriberdata" has been inserted.
 --
--- This results in the same behaviour of the deocder/encoder but
--- means only a replication of the ASN.1 definiton here.
+-- This results in the same behaviour of the decoder/encoder but
+-- means only a replication of the ASN.1 definition here.
 --
     msisdn              [1]  ISDN-AddressString       OPTIONAL,
     category            [2]  Category                 OPTIONAL,
diff --git a/lib/asn1/test/asn1_SUITE_data/Nortel.asn b/lib/asn1/test/asn1_SUITE_data/Nortel.asn
index a27c78a0b5..57a4434f2e 100644
--- a/lib/asn1/test/asn1_SUITE_data/Nortel.asn
+++ b/lib/asn1/test/asn1_SUITE_data/Nortel.asn
@@ -153,7 +153,7 @@ LocationAreaCode		::= OCTET STRING (SIZE(2))
 
 CallEventRecord	::= CHOICE
 {
--- Record values 0..16 are 3G curcuit switch specifick
+-- Record values 0..16 are 3G circuit switch specifick
 --
 --	sgsnPDPRecord		[20] SGSNPDPRecord,
 	ggsnPDPRecord		[21] GGSNPDPRecord
@@ -372,7 +372,7 @@ FFDAppendIndicator	::= BOOLEAN
 
 FreeFormatData	::=	OCTET STRING (SIZE(1..160))
 	--
-	-- Free formated data as sent in the FurnishChargingInformationGPRS
+	-- Free formatted data as sent in the FurnishChargingInformationGPRS
 	-- see TS 29.078
 	--
 
diff --git a/lib/asn1/test/asn1_SUITE_data/PKIX1Explicit93.asn1 b/lib/asn1/test/asn1_SUITE_data/PKIX1Explicit93.asn1
index 714a682160..01c5be2166 100644
--- a/lib/asn1/test/asn1_SUITE_data/PKIX1Explicit93.asn1
+++ b/lib/asn1/test/asn1_SUITE_data/PKIX1Explicit93.asn1
@@ -172,7 +172,7 @@ EntryExtensionSet       EXTENSION       ::=     { reasonCode |
                                                 invalidityDate |
                                                 certificateIssuer }
 
-         -- information object classes used in the defintion --
+         -- information object classes used in the definition --
                     -- of certificates and CRLs --
 
 -- Parameterized Type SIGNED --
diff --git a/lib/asn1/test/asn1_SUITE_data/RANAP.asn1 b/lib/asn1/test/asn1_SUITE_data/RANAP.asn1
index 55fb58b163..e821703036 100644
--- a/lib/asn1/test/asn1_SUITE_data/RANAP.asn1
+++ b/lib/asn1/test/asn1_SUITE_data/RANAP.asn1
@@ -872,7 +872,7 @@ RAB-Parameters ::= SEQUENCE {
 	transferDelay			TransferDelay OPTIONAL
 	-- This IE is only present when traffic class indicates Conversational or Streaming --,
 	trafficHandlingPriority		TrafficHandlingPriority OPTIONAL
-	-- This IE is only present when traffic class indicates Interactiv --,
+	-- This IE is only present when traffic class indicates Interactive --,
 	allocationOrRetentionPriority	AllocationOrRetentionPriority OPTIONAL,
 	sourceStatisticsDescriptor	SourceStatisticsDescriptor OPTIONAL
 	-- This IE is only present when traffic class indicates Conversational or Streaming --,
@@ -1640,7 +1640,7 @@ RelocationCancelAcknowledgeExtensions RANAP-PROTOCOL-EXTENSION ::= {
 
 -- **************************************************************
 --
--- SRNS CONTEXT TRANSFER OPEARATION
+-- SRNS CONTEXT TRANSFER OPERATION
 --
 -- **************************************************************
 
diff --git a/lib/asn1/test/asn1_SUITE_data/SwCDR.py b/lib/asn1/test/asn1_SUITE_data/SwCDR.py
index 9492183cdf..1ed9c32aba 100644
--- a/lib/asn1/test/asn1_SUITE_data/SwCDR.py
+++ b/lib/asn1/test/asn1_SUITE_data/SwCDR.py
@@ -199,7 +199,7 @@ StartDate			::=	OCTET STRING (SIZE (8))
 StartTime			::=	OCTET STRING (SIZE (6))
 
 CallDuration			::=	INTEGER
---	Expressed as number of millseconds
+--	Expressed as number of milliseconds
 
 Cellrate			::=	INTEGER
 --	Value range 0-2^64
diff --git a/lib/asn1/test/asn1_SUITE_data/nbapsystem/NBAP-PDU-Contents.asn b/lib/asn1/test/asn1_SUITE_data/nbapsystem/NBAP-PDU-Contents.asn
index 9ecfa688a2..b614e86bba 100644
--- a/lib/asn1/test/asn1_SUITE_data/nbapsystem/NBAP-PDU-Contents.asn
+++ b/lib/asn1/test/asn1_SUITE_data/nbapsystem/NBAP-PDU-Contents.asn
@@ -5606,13 +5606,13 @@ DL-CCTrCH-InformationAddItem-RL-ReconfPrepTDD-ExtIEs  NBAP-PROTOCOL-EXTENSION ::
 	{ ID id-DL-DPCH-LCR-InformationAddList-RL-ReconfPrepTDD				CRITICALITY reject	EXTENSION DL-DPCH-LCR-InformationAddList-RL-ReconfPrepTDD		PRESENCE optional }|	-- Applicable to 1.28Mcps TDD only
 -- This DPCH Information is the for the first RL repetition, DPCH information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
 	{ ID id-CCTrCH-Initial-DL-Power-RL-ReconfPrepTDD					CRITICALITY ignore	EXTENSION DL-Power	PRESENCE optional	}|
--- This DL Power inforrmation is the for the first RL repetition, DL power information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
+-- This DL Power information is the for the first RL repetition, DL power information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
 	{ ID id-TDD-TPC-DownlinkStepSize-InformationAdd-RL-ReconfPrepTDD	CRITICALITY reject	EXTENSION  TDD-TPC-DownlinkStepSize	 PRESENCE optional}|
 -- This DL step size is the for the first RL repetition, DL step size information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
 	{ ID id-CCTrCH-Maximum-DL-Power-InformationAdd-RL-ReconfPrepTDD		CRITICALITY ignore	EXTENSION DL-Power	PRESENCE optional	}|
--- This DL Power inforrmation is the for the first RL repetition, DL power information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
+-- This DL Power information is the for the first RL repetition, DL power information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
 	{ ID id-CCTrCH-Minimum-DL-Power-InformationAdd-RL-ReconfPrepTDD		CRITICALITY ignore	EXTENSION DL-Power	PRESENCE optional	}|
--- This DL Power inforrmation is the for the first RL repetition, DL power information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
+-- This DL Power information is the for the first RL repetition, DL power information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
 	{ ID id-RL-ID														CRITICALITY ignore	EXTENSION RL-ID	PRESENCE optional	}|
 -- This is the RL ID for the first RL repetition
 	{ ID id-multipleRL-ul-DPCH-InformationList							CRITICALITY reject	EXTENSION MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD	PRESENCE optional	},
diff --git a/lib/asn1/test/asn1_SUITE_data/rfcs/AlgorithmInformation-2009.asn1 b/lib/asn1/test/asn1_SUITE_data/rfcs/AlgorithmInformation-2009.asn1
index f912966c72..7da299c789 100644
--- a/lib/asn1/test/asn1_SUITE_data/rfcs/AlgorithmInformation-2009.asn1
+++ b/lib/asn1/test/asn1_SUITE_data/rfcs/AlgorithmInformation-2009.asn1
@@ -50,7 +50,7 @@ ParamOptions ::= ENUMERATED {
 --  Additional information such as the length of the hash could have
 --      been encoded.  Without a clear understanding of what information
 --      is needed by applications, such extraneous information was not
---      considered to be of sufficent importance.
+--      considered to be of sufficient importance.
 --
 --  Example:
 --  mda-sha1 DIGEST-ALGORITHM ::= {
diff --git a/lib/asn1/test/asn1_SUITE_data/rfcs/ISO8571-FTAM.asn1 b/lib/asn1/test/asn1_SUITE_data/rfcs/ISO8571-FTAM.asn1
index a57a276704..3765eb5b65 100644
--- a/lib/asn1/test/asn1_SUITE_data/rfcs/ISO8571-FTAM.asn1
+++ b/lib/asn1/test/asn1_SUITE_data/rfcs/ISO8571-FTAM.asn1
@@ -286,7 +286,7 @@ F-OPEN-response ::= SEQUENCE {
   -- This flag is set if the responder is going to follow this response
   -- by a P-ALTER-CONTEXT exchange.
   --The following are conditional on the negotiation of the concecutive access
-  -- or concurent access functional units.
+  -- or concurrent access functional units.
   degree-of-overlap       Degree-Of-Overlap OPTIONAL,
   transfer-window         [7] IMPLICIT INTEGER OPTIONAL
 }
@@ -571,7 +571,7 @@ Change-Attributes ::= [APPLICATION 8] IMPLICIT SEQUENCE {
 
 -- This Parameter tan only be sent when the
 -- enhanced-filestore-management functional unit is available.
--- Atleast one attribute shall be present in the Change-Attributes
+-- At least one attribute shall be present in the Change-Attributes
 -- Parameter on the request PDU.
 Charging ::=
   [APPLICATION 9] IMPLICIT
@@ -1350,7 +1350,7 @@ Attribute-Extensions-Pattern ::=
                                                 {@.extension-attribute-identifier})
                                }}
 
--- conjunction with the extention attribute in Order to
+-- conjunction with the extension attribute in Order to
 -- perform Pattern matthing operations on it. it may be
 -- defined in terms of other Patterns within this
 -- Standard.
diff --git a/lib/asn1/test/asn1_SUITE_data/tcapsystem/MAP-MS-DataTypes.asn b/lib/asn1/test/asn1_SUITE_data/tcapsystem/MAP-MS-DataTypes.asn
index e905c44077..46c919b772 100644
--- a/lib/asn1/test/asn1_SUITE_data/tcapsystem/MAP-MS-DataTypes.asn
+++ b/lib/asn1/test/asn1_SUITE_data/tcapsystem/MAP-MS-DataTypes.asn
@@ -2100,7 +2100,7 @@ LocationInformation ::= SEQUENCE {
 -- sai-Present indicates that the cellGlobalIdOrServiceAreaIdOrLAI parameter contains
 -- a Service Area Identity.
 -- currentLocationRetrieved shall be present 
--- if the location information were retrieved after a successfull paging.
+-- if the location information were retrieved after a successful paging.
 
 LocationInformationGPRS ::= SEQUENCE {
 	cellGlobalIdOrServiceAreaIdOrLAI	[0] CellGlobalIdOrServiceAreaIdOrLAI OPTIONAL,
diff --git a/lib/asn1/test/syntax_SUITE.erl b/lib/asn1/test/syntax_SUITE.erl
index 16eb669813..5dc964845d 100644
--- a/lib/asn1/test/syntax_SUITE.erl
+++ b/lib/asn1/test/syntax_SUITE.erl
@@ -187,7 +187,7 @@ objects(Config) ->
 	  {"{&min 1, Max 10}",3,{syntax_error,'Max'}},
 	  {"{min 1, &max 10}",3,{syntax_error,'&max'}},
 	  {"{min 1, &Max 10}",3,{syntax_error,'&Max'}},
-	  {"{RESERVERD WORD BIT}",3,{syntax_error,'BIT'}},
+	  {"{RESERVED WORD BIT}",3,{syntax_error,'BIT'}},
 	  {"{&min 1",4,{syntax_error,'END'}}
 	 ],
     L = [{Head++S++End,Line,E} || {S,Line,E} <- L0],
diff --git a/lib/asn1/test/asn1_SUITE_data/testobj.erl b/lib/asn1/test/asn1_SUITE_data/testobj.erl
index b582935f73..375994f740 100644
--- a/lib/asn1/test/asn1_SUITE_data/testobj.erl
+++ b/lib/asn1/test/asn1_SUITE_data/testobj.erl
@@ -427,7 +427,7 @@ run_sm_cmd() ->
 	  {_ProtIEField2,11,_Crit2,DecEI},
 	  {_ProtIEField3,75,_Crit3,DecKS}],
 	 _ASN1novalue} ->
-	    io:format("Integrity Protection Algoritm: ~w~n~n", [DecIPI]),
+	    io:format("Integrity Protection Algorithm: ~w~n~n", [DecIPI]),
 	    io:format("Encryption Information: ~w~n~n", [DecEI]),
 	    io:format("Key Status: ~w~n~n", [DecKS])
     end,
@@ -452,7 +452,7 @@ run_sm_cmp() ->
 	 [{_ProtIEField1,6,_Crit1,DecIPA},
 	  {_ProtIEField2,5,_Crit2,DecEI}],
 	 _ASN1novalue} ->
-	    io:format("Integrity Protection Algoritm: ~w~n~n", [DecIPA]),
+	    io:format("Integrity Protection Algorithm: ~w~n~n", [DecIPA]),
 	    io:format("Encryption Information: ~w~n~n", [DecEI])
     end,
     ok.
@@ -480,7 +480,7 @@ run_sm_rej() ->
 % 	    io:format("Value2: ~w~n~n", [Value2]),
 % 	    {ok,DecIPA} = wrapper_decode(?ranap, 'IntegrityProtectionAlgorithm', Value1),
 % 	    {ok,DecEI} = wrapper_decode(?ranap, 'EncryptionAlgorithm', Value2),
 % 	    io:format("Integrity Protection Algoritm: ~w~n~n", [DecIPA]),
 % 	    io:format("Encryption Information: ~w~n~n", [DecEI])
 %     end,
     ok.
@@ -563,7 +563,7 @@ run_reset() ->
 
 run_reset_res() ->
     IUP = reset_res([12,13,14,15,16,17,18,19,20]),
-    io:format("Reset Rsource: ~w~n~n", [IUP]),
+    io:format("Reset Resource: ~w~n~n", [IUP]),
     RanapIUP = ranap_pdu_contents(IUP, 27),            % 27 = Reset Res
     {ok, Tmp2} = wrapper_encode(?ranap, 'RANAP-PDU', RanapIUP),
     EncRanapIUP = lists:flatten(Tmp2),
@@ -1390,7 +1390,7 @@ reset_res_ack(IuSCId) ->
 reset_res_ack_ies(IuSCId) ->
     [
      cn_domain_ind()       % Se initial Ue
-     ,reset_res_list(IuSCId)     % Se Reset Ressource
+     ,reset_res_list(IuSCId)     % Se Reset Resource
     ].
 
 
@@ -480,7 +480,7 @@ run_sm_rej() ->
 % 	    {ok,DecIPA} = wrapper_decode(?ranap, 'IntegrityProtectionAlgorithm', Value1),
 % 	    {ok,DecEI} = wrapper_decode(?ranap, 'EncryptionAlgorithm', Value2),
-% 	    io:format("Integrity Protection Algoritm: ~w~n~n", [DecIPA]),
+% 	    io:format("Integrity Protection Algorithm: ~w~n~n", [DecIPA]),
 % 	    io:format("Encryption Information: ~w~n~n", [DecEI])
 %     end,
-- 
2.31.1

openSUSE Build Service is sponsored by